# PyIonoSeis


[![image](https://img.shields.io/pypi/v/pyionoseis.svg)](https://pypi.python.org/pypi/pyionoseis)
[![image](https://img.shields.io/conda/vn/conda-forge/pyionoseis.svg)](https://anaconda.org/conda-forge/pyionoseis)


**A python package for modeling and anlaysis of coseismic ionospheric disturbances**


-   Free software: MIT License
-   Documentation: https://dylanmikesell.github.io/pyionoseis
    

## Features

-   TODO
